==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/collection/request/PhonecallCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Phonecall;
import microsoft.dynamics.crm.entity.request.ActioncardRequest;
import microsoft.dynamics.crm.entity.request.ActivitypartyRequest;
import microsoft.dynamics.crm.entity.request.AnnotationRequest;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.ConnectionRequest;
import microsoft.dynamics.crm.entity.request.DuplicaterecordRequest;
import microsoft.dynamics.crm.entity.request.PhonecallRequest;
import microsoft.dynamics.crm.entity.request.PostfollowRequest;
import microsoft.dynamics.crm.entity.request.PostregardingRequest;
import microsoft.dynamics.crm.entity.request.PrincipalobjectattributeaccessRequest;
import microsoft.dynamics.crm.entity.request.ProcesssessionRequest;
import microsoft.dynamics.crm.entity.request.QueueitemRequest;
import microsoft.dynamics.crm.entity.request.SlakpiinstanceRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

public class PhonecallCollectionRequest extends CollectionPageEntityRequest<Phonecall, PhonecallRequest>{

    protected ContextPath contextPath;

    public PhonecallCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Phonecall.class, cp -> new PhonecallRequest(cp, Optional.empty()), SchemaInfo.INSTANCE, value);
        this.contextPath = contextPath;
    }

    public PostregardingCollectionRequest phonecall_PostRegardings() {
        return new PostregardingCollectionRequest(contextPath.addSegment("phonecall_PostRegardings"), Optional.empty());
    }

    public PostregardingRequest phonecall_PostRegardings(String postregardingid) {
        return new PostregardingRequest(contextPath.addSegment("phonecall_PostRegardings").addKeys(new NameValue(postregardingid.toString())), Optional.empty());
    }

    public PostfollowCollectionRequest phonecall_PostFollows() {
        return new PostfollowCollectionRequest(contextPath.addSegment("phonecall_PostFollows"), Optional.empty());
    }

    public PostfollowRequest phonecall_PostFollows(String postfollowid) {
        return new PostfollowRequest(contextPath.addSegment("phonecall_PostFollows").addKeys(new NameValue(postfollowid.toString())), Optional.empty());
    }

    public ActioncardCollectionRequest phonecall_actioncard() {
        return new ActioncardCollectionRequest(contextPath.addSegment("phonecall_actioncard"), Optional.empty());
    }

    public ActioncardRequest phonecall_actioncard(String actioncardid) {
        return new ActioncardRequest(contextPath.addSegment("phonecall_actioncard").addKeys(new NameValue(actioncardid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest phoneCall_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("PhoneCall_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest phoneCall_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("PhoneCall_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest phoneCall_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("PhoneCall_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest phoneCall_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("PhoneCall_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public ActivitypartyCollectionRequest phonecall_activity_parties() {
        return new ActivitypartyCollectionRequest(contextPath.addSegment("phonecall_activity_parties"), Optional.empty());
    }

    public ActivitypartyRequest phonecall_activity_parties(String activitypartyid) {
        return new ActivitypartyRequest(contextPath.addSegment("phonecall_activity_parties").addKeys(new NameValue(activitypartyid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest phoneCall_ProcessSessions() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("PhoneCall_ProcessSessions"), Optional.empty());
    }

    public ProcesssessionRequest phoneCall_ProcessSessions(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("PhoneCall_ProcessSessions").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest phoneCall_DuplicateMatchingRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("PhoneCall_DuplicateMatchingRecord"), Optional.empty());
    }

    public DuplicaterecordRequest phoneCall_DuplicateMatchingRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("PhoneCall_DuplicateMatchingRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest phoneCall_DuplicateBaseRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("PhoneCall_DuplicateBaseRecord"), Optional.empty());
    }

    public DuplicaterecordRequest phoneCall_DuplicateBaseRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("PhoneCall_DuplicateBaseRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public ConnectionCollectionRequest phonecall_connections1() {
        return new ConnectionCollectionRequest(contextPath.addSegment("phonecall_connections1"), Optional.empty());
    }

    public ConnectionRequest phonecall_connections1(String connectionid) {
        return new ConnectionRequest(contextPath.addSegment("phonecall_connections1").addKeys(new NameValue(connectionid.toString())), Optional.empty());
    }

    public SlakpiinstanceCollectionRequest slakpiinstance_phonecall() {
        return new SlakpiinstanceCollectionRequest(contextPath.addSegment("slakpiinstance_phonecall"), Optional.empty());
    }

    public SlakpiinstanceRequest slakpiinstance_phonecall(String slakpiinstanceid) {
        return new SlakpiinstanceRequest(contextPath.addSegment("slakpiinstance_phonecall").addKeys(new NameValue(slakpiinstanceid.toString())), Optional.empty());
    }

    public SyncerrorCollectionRequest phoneCall_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("PhoneCall_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest phoneCall_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("PhoneCall_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public QueueitemCollectionRequest phoneCall_QueueItem() {
        return new QueueitemCollectionRequest(contextPath.addSegment("PhoneCall_QueueItem"), Optional.empty());
    }

    public QueueitemRequest phoneCall_QueueItem(String queueitemid) {
        return new QueueitemRequest(contextPath.addSegment("PhoneCall_QueueItem").addKeys(new NameValue(queueitemid.toString())), Optional.empty());
    }

    public AnnotationCollectionRequest phoneCall_Annotation() {
        return new AnnotationCollectionRequest(contextPath.addSegment("PhoneCall_Annotation"), Optional.empty());
    }

    public AnnotationRequest phoneCall_Annotation(String annotationid) {
        return new AnnotationRequest(contextPath.addSegment("PhoneCall_Annotation").addKeys(new NameValue(annotationid.toString())), Optional.empty());
    }

    public ConnectionCollectionRequest phonecall_connections2() {
        return new ConnectionCollectionRequest(contextPath.addSegment("phonecall_connections2"), Optional.empty());
    }

    public ConnectionRequest phonecall_connections2(String connectionid) {
        return new ConnectionRequest(contextPath.addSegment("phonecall_connections2").addKeys(new NameValue(connectionid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest phonecall_principalobjectattributeaccess() {
        return new PrincipalobjectattributeaccessCollectionRequest(contextPath.addSegment("phonecall_principalobjectattributeaccess"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest phonecall_principalobjectattributeaccess(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("phonecall_principalobjectattributeaccess").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/collection/request/PhonecallCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Phonecall;
import microsoft.dynamics.crm.entity.request.ActioncardRequest;
import microsoft.dynamics.crm.entity.request.ActivitypartyRequest;
import microsoft.dynamics.crm.entity.request.AnnotationRequest;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.ConnectionRequest;
import microsoft.dynamics.crm.entity.request.DuplicaterecordRequest;
import microsoft.dynamics.crm.entity.request.PhonecallRequest;
import microsoft.dynamics.crm.entity.request.PostfollowRequest;
import microsoft.dynamics.crm.entity.request.PostregardingRequest;
import microsoft.dynamics.crm.entity.request.PrincipalobjectattributeaccessRequest;
import microsoft.dynamics.crm.entity.request.ProcesssessionRequest;
import microsoft.dynamics.crm.entity.request.QueueitemRequest;
import microsoft.dynamics.crm.entity.request.SlakpiinstanceRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;

public class PhonecallCollectionRequest extends CollectionPageEntityRequest<Phonecall, PhonecallRequest>{

    protected ContextPath contextPath;

    public PhonecallCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Phonecall.class, cp -> new PhonecallRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    public PostregardingCollectionRequest phonecall_PostRegardings() {
        return new PostregardingCollectionRequest(contextPath.addSegment("phonecall_PostRegardings"), Optional.empty());
    }

    public PostregardingRequest phonecall_PostRegardings(String postregardingid) {
        return new PostregardingRequest(contextPath.addSegment("phonecall_PostRegardings").addKeys(new NameValue(postregardingid.toString())), Optional.empty());
    }

    public PostfollowCollectionRequest phonecall_PostFollows() {
        return new PostfollowCollectionRequest(contextPath.addSegment("phonecall_PostFollows"), Optional.empty());
    }

    public PostfollowRequest phonecall_PostFollows(String postfollowid) {
        return new PostfollowRequest(contextPath.addSegment("phonecall_PostFollows").addKeys(new NameValue(postfollowid.toString())), Optional.empty());
    }

    public ActioncardCollectionRequest phonecall_actioncard() {
        return new ActioncardCollectionRequest(contextPath.addSegment("phonecall_actioncard"), Optional.empty());
    }

    public ActioncardRequest phonecall_actioncard(String actioncardid) {
        return new ActioncardRequest(contextPath.addSegment("phonecall_actioncard").addKeys(new NameValue(actioncardid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest phoneCall_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("PhoneCall_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest phoneCall_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("PhoneCall_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest phoneCall_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("PhoneCall_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest phoneCall_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("PhoneCall_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public ActivitypartyCollectionRequest phonecall_activity_parties() {
        return new ActivitypartyCollectionRequest(contextPath.addSegment("phonecall_activity_parties"), Optional.empty());
    }

    public ActivitypartyRequest phonecall_activity_parties(String activitypartyid) {
        return new ActivitypartyRequest(contextPath.addSegment("phonecall_activity_parties").addKeys(new NameValue(activitypartyid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest phoneCall_ProcessSessions() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("PhoneCall_ProcessSessions"), Optional.empty());
    }

    public ProcesssessionRequest phoneCall_ProcessSessions(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("PhoneCall_ProcessSessions").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest phoneCall_DuplicateMatchingRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("PhoneCall_DuplicateMatchingRecord"), Optional.empty());
    }

    public DuplicaterecordRequest phoneCall_DuplicateMatchingRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("PhoneCall_DuplicateMatchingRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest phoneCall_DuplicateBaseRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("PhoneCall_DuplicateBaseRecord"), Optional.empty());
    }

    public DuplicaterecordRequest phoneCall_DuplicateBaseRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("PhoneCall_DuplicateBaseRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public ConnectionCollectionRequest phonecall_connections1() {
        return new ConnectionCollectionRequest(contextPath.addSegment("phonecall_connections1"), Optional.empty());
    }

    public ConnectionRequest phonecall_connections1(String connectionid) {
        return new ConnectionRequest(contextPath.addSegment("phonecall_connections1").addKeys(new NameValue(connectionid.toString())), Optional.empty());
    }

    public SlakpiinstanceCollectionRequest slakpiinstance_phonecall() {
        return new SlakpiinstanceCollectionRequest(contextPath.addSegment("slakpiinstance_phonecall"), Optional.empty());
    }

    public SlakpiinstanceRequest slakpiinstance_phonecall(String slakpiinstanceid) {
        return new SlakpiinstanceRequest(contextPath.addSegment("slakpiinstance_phonecall").addKeys(new NameValue(slakpiinstanceid.toString())), Optional.empty());
    }

    public SyncerrorCollectionRequest phoneCall_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("PhoneCall_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest phoneCall_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("PhoneCall_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public QueueitemCollectionRequest phoneCall_QueueItem() {
        return new QueueitemCollectionRequest(contextPath.addSegment("PhoneCall_QueueItem"), Optional.empty());
    }

    public QueueitemRequest phoneCall_QueueItem(String queueitemid) {
        return new QueueitemRequest(contextPath.addSegment("PhoneCall_QueueItem").addKeys(new NameValue(queueitemid.toString())), Optional.empty());
    }

    public AnnotationCollectionRequest phoneCall_Annotation() {
        return new AnnotationCollectionRequest(contextPath.addSegment("PhoneCall_Annotation"), Optional.empty());
    }

    public AnnotationRequest phoneCall_Annotation(String annotationid) {
        return new AnnotationRequest(contextPath.addSegment("PhoneCall_Annotation").addKeys(new NameValue(annotationid.toString())), Optional.empty());
    }

    public ConnectionCollectionRequest phonecall_connections2() {
        return new ConnectionCollectionRequest(contextPath.addSegment("phonecall_connections2"), Optional.empty());
    }

    public ConnectionRequest phonecall_connections2(String connectionid) {
        return new ConnectionRequest(contextPath.addSegment("phonecall_connections2").addKeys(new NameValue(connectionid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest phonecall_principalobjectattributeaccess() {
        return new PrincipalobjectattributeaccessCollectionRequest(contextPath.addSegment("phonecall_principalobjectattributeaccess"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest phonecall_principalobjectattributeaccess(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("phonecall_principalobjectattributeaccess").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

}
